@@ -24,6 +24,7 @@
 #endif
 
 #include <iostream>
+#include <iomanip>
 #include <fcntl.h>
 
 #include "pdnsexception.hh"
@@ -32,6 +33,8 @@
 #include "namespaces.hh"
 #include "rec_channel.hh"
 #include "settings/cxxsettings.hh"
+#include "logger.hh"
+#include "logging.hh"
 
 ArgvMap& arg()
 {
@@ -39,7 +42,7 @@ ArgvMap& arg()
   return arg;
 }
 
-static void initArguments(int argc, char** argv)
+static void initArguments(int argc, char** argv, Logr::log_t log)
 {
   arg().set("config-dir", "Location of configuration directory (recursor.conf)") = SYSCONFDIR;
 
@@ -71,26 +74,33 @@ static void initArguments(int argc, char** argv)
 
   cleanSlashes(configname);
 
-  const string yamlconfigname = configname + ".yml";
   string msg;
   pdns::rust::settings::rec::Recursorsettings settings;
+  pdns::settings::rec::YamlSettingsStatus yamlstatus{};
 
-  auto yamlstatus = pdns::settings::rec::readYamlSettings(yamlconfigname, "", settings, msg, g_slog);
+  for (const string suffix : {".yml", ".conf"}) {
+    const string yamlconfigname = configname + suffix;
+    yamlstatus = pdns::settings::rec::readYamlSettings(yamlconfigname, "", settings, msg, g_slog);
 
-  switch (yamlstatus) {
-  case pdns::settings::rec::YamlSettingsStatus::CannotOpen:
-    break;
-  case pdns::settings::rec::YamlSettingsStatus::PresentButFailed:
-    cerr << "YAML config found for configname '" << yamlconfigname << "' but error ocurred processing it" << endl;
-    exit(1); // NOLINT(concurrency-mt-unsafe)
-    break;
-  case pdns::settings::rec::YamlSettingsStatus::OK:
-    cerr << "YAML config found and processed for configname '" << yamlconfigname << "'" << endl;
-    pdns::settings::rec::bridgeStructToOldStyleSettings(settings);
-    break;
+    switch (yamlstatus) {
+    case pdns::settings::rec::YamlSettingsStatus::CannotOpen:
+      break;
+    case pdns::settings::rec::YamlSettingsStatus::PresentButFailed:
+      if (suffix == ".yml") {
+        log->error(Logr::Error, msg, "YAML config found, but error ocurred processing it", "configname", Logging::Loggable(yamlconfigname));
+        exit(1); // NOLINT(concurrency-mt-unsafe)
+      }
+      break;
+    case pdns::settings::rec::YamlSettingsStatus::OK:
+      log->info(Logr::Notice, "YAML config found and processed", "configname", Logging::Loggable(yamlconfigname));
+      pdns::settings::rec::bridgeStructToOldStyleSettings(settings);
+      break;
+    }
+    if (yamlstatus == pdns::settings::rec::YamlSettingsStatus::OK) {
+      break;
+    }
   }
-
-  if (yamlstatus == pdns::settings::rec::YamlSettingsStatus::CannotOpen) {
+  if (yamlstatus != pdns::settings::rec::YamlSettingsStatus::OK) {
     configname += ".conf";
     arg().laxFile(configname);
   }
@@ -108,6 +118,41 @@ static void initArguments(int argc, char** argv)
   }
 }
 
+static std::string showLuaYAML(const ::rust::string& rfile)
+{
+  std::string msg;
+  if (rfile.empty()) {
+    return msg;
+  }
+
+  const auto file = string(rfile);
+  ProxyMapping proxyMapping;
+  LuaConfigItems lci;
+
+  try {
+    loadRecursorLuaConfig(file, proxyMapping, lci);
+    auto settings = pdns::rust::settings::rec::parse_yaml_string("");
+    pdns::settings::rec::fromLuaConfigToBridgeStruct(lci, proxyMapping, settings);
+    auto yaml = settings.to_yaml_string();
+    msg += "# Start of converted Lua config .yml based on " + file + "\n";
+    msg += std::string(yaml);
+    msg += "# Validation result: ";
+    try {
+      // Parse back and validate
+      settings.validate();
+      msg += "OK";
+    }
+    catch (const rust::Error& err) {
+      msg += err.what();
+    }
+    msg += "\n# End of converted " + file + "\n#\n";
+  }
+  catch (PDNSException& e) {
+    cerr << "Cannot load Lua configuration: " << e.reason << endl;
+  }
+  return msg;
+}
+
 static std::string showIncludeYAML(::rust::String& rdirname)
 {
   std::string msg;
@@ -217,12 +262,13 @@ static RecursorControlChannel::Answer showYAML(const std::string& path)
     }
     msg += "\n# End of converted " + configName + "\n#\n";
 
+    msg += showLuaYAML(mainsettings.recursor.lua_config_file);
     msg += showIncludeYAML(mainsettings.recursor.include_dir);
     msg += showForwardFileYAML(mainsettings.recursor.forward_zones_file);
     msg += showAllowYAML(mainsettings.incoming.allow_from_file, "incoming", "allow_from_file", pdns::rust::settings::rec::validate_allow_from);
     msg += showAllowYAML(mainsettings.incoming.allow_notify_from_file, "incoming", "allow_notify_from_file", pdns::rust::settings::rec::validate_allow_from);
     msg += showAllowYAML(mainsettings.incoming.allow_notify_for_file, "incoming", "allow_notify_for_file", pdns::rust::settings::rec::validate_allow_for);
-    return {0, msg};
+    return {0, std::move(msg)};
   }
   catch (const rust::Error& err) {
     return {1, std::string(err.what())};
@@ -235,9 +281,48 @@ static RecursorControlChannel::Answer showYAML(const std::string& path)
   }
 }
 
+static void recControlLoggerBackend(const Logging::Entry& entry)
+{
+  static thread_local std::stringstream buf;
+
+  // First map SL priority to syslog's Urgency
+  Logger::Urgency urg = entry.d_priority != 0 ? Logger::Urgency(entry.d_priority) : Logger::Info;
+  if (urg > Logger::Warning) {
+    // We do not log anything if the Urgency of the message is lower than the requested loglevel.
+    // Not that lower Urgency means higher number.
+    return;
+  }
+  buf.str("");
+  buf << "msg=" << std::quoted(entry.message);
+  if (entry.error) {
+    buf << " error=" << std::quoted(entry.error.get());
+  }
+
+  if (entry.name) {
+    buf << " subsystem=" << std::quoted(entry.name.get());
+  }
+  buf << " level=" << std::quoted(std::to_string(entry.level));
+  if (entry.d_priority != 0) {
+    buf << " prio=" << std::quoted(Logr::Logger::toString(entry.d_priority));
+  }
+
+  std::array<char, 64> timebuf{};
+  buf << " ts=" << std::quoted(Logging::toTimestampStringMilli(entry.d_timestamp, timebuf));
+
+  for (auto const& value : entry.values) {
+    buf << " ";
+    buf << value.first << "=" << std::quoted(value.second);
+  }
+
+  cerr << buf.str() << endl;
+}
+
 int main(int argc, char** argv)
 {
-  g_slogStructured = false;
+  g_slog = Logging::Logger::create(recControlLoggerBackend);
+  auto log = g_slog->withName("config");
+  ::arg().setSLog(log);
+
   const set<string> fileCommands = {
     "dump-cache",
     "dump-edns",
@@ -252,7 +337,7 @@ int main(int argc, char** argv)
     "trace-regex",
   };
   try {
-    initArguments(argc, argv);
+    initArguments(argc, argv, log);
     string sockname = "pdns_recursor";
 
     if (arg()["config-name"] != "")
@@ -343,7 +428,7 @@ int main(int argc, char** argv)
     auto timeout = arg().asNum("timeout");
     RecursorControlChannel rccS;
     rccS.connect(arg()["socket-dir"], sockname);
-    rccS.send(rccS.d_fd, {0, command}, timeout, fd);
+    rccS.send(rccS.d_fd, {0, std::move(command)}, timeout, fd);
 
     auto receive = rccS.recv(rccS.d_fd, timeout);
     if (receive.d_ret != 0) {
@@ -355,7 +440,7 @@ int main(int argc, char** argv)
     return receive.d_ret;
   }
   catch (PDNSException& ae) {
-    cerr << "Fatal: " << ae.reason << "\n";
+    log->error(Logr::Error, ae.reason, "Fatal");
     return 1;
   }
 }
